PCB Environment: ResultRecord Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
ResultRecord Struct Reference

## Public Member Functions
| ResultRecord (const Agent &, const Action::Result &)
| ResultRecord (const Agent &)
Action::Result | asResult () const
void | reset (bool success, Reward r=std::numeric_limits< Reward >::infinity())
std::string | str () const
PyObject * | getPy () const

## Data Fields
Reward | RewardSum
bool | Success
RouterResult | Router
uint64_t | TimeMicroseconds
uint64_t | TimeStep
uint64_t | Iteration

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Stats.hpp